==> gatsby-plugin-ada-chatbot-1.4.0.tgz: package/src/actions.js <==
const {
  adaRootSelector,
  getAdaRoot,
  chatFrameSelector,
} = require('./elements');

let transformStyles = null;

const setVisible = (visibility = true) => {
  const adaRoot = getAdaRoot();
  if (adaRoot) {
    if (visibility) adaRoot.classList.add('ada-chatbot-visible');
    else adaRoot.classList.remove('ada-chatbot-visible');
  }
};

const setZIndex = (zIndex) => {
  const adaRoot = getAdaRoot();
  if (adaRoot) adaRoot.style.zIndex = zIndex;
};

const dismiss = (pluginOptions) => {
  try {
    const { dismissDuration } = pluginOptions;

    document.documentElement.classList.add('ada-chatbot-dismissed');

    if (dismissDuration === 'session') {
      sessionStorage.setItem('ada-chatbot-dismissed', 'true');
    } else if (typeof dismissDuration === 'number') {
      const expires = Date.now() + (dismissDuration * 60 * 60 *1000);
      localStorage.setItem('ada-chatbot-dismissed', 'true');
      localStorage.setItem('ada-chatbot-dismiss-expires', expires);
    }
    
    return true;
  } catch(e) {
    return false;
  }
};

const adaReadyCallbacks = [];
const onAdaReady = (callback) => {
  if (typeof callback === 'function') adaReadyCallbacks.push(callback);
  if (window.adaEmbed) {
    adaReadyCallbacks.forEach(callback => callback(window.adaEmbed));
    adaReadyCallbacks = [];
  }
};

const chatOpenedCallbacks = [];
const onChatOpened = (callback) => {
  if (typeof callback === 'function') chatOpenedCallbacks.push(callback);
};

const chatClosedCallbacks = [];
const onChatClosed = (callback) => {
  if (typeof callback === 'function') chatClosedCallbacks.push(callback);
};

const toggleChat = async () => {
  if (window && window.adaEmbed) {
    setVisible(true);
    const toggled = await window.adaEmbed.toggle();
    return toggled;
  }
  return false;
};

const chatToggleCallback = (isChatOpen) => {
  if (isChatOpen) {
    document.documentElement.classList.add('ada-chatbot-chat-open');
    chatOpenedCallbacks.forEach(callback => callback(window.adaEmbed));
  }
  else {
    document.documentElement.classList.remove('ada-chatbot-chat-open');
    chatClosedCallbacks.forEach(callback => callback(window.adaEmbed));
  }
};

const animateTransform = ({ x = 0, y = 0, duration = 150, easing = 'ease-in-out' } = {}) => {
  const adaRoot = getAdaRoot();
  const transform = `translate(${x}px, ${y}px)`;
  const transition = `transform ${duration}ms ${easing}`;

  if (!transformStyles) transformStyles = document.createElement('style');

  transformStyles.innerHTML = `
    ${adaRootSelector} {
      transition: ${transition};
      transform: ${transform};
    }

    ${chatFrameSelector} {
      margin-bottom: ${y}px !important;
      margin-right: ${x}px !important;
    }
  `;

  if (adaRoot) adaRoot.appendChild(transformStyles);
};

/* Temporarily removed
const avoidPrivacyPolicy = () => {
  window.addEventListener('load', init, false);
  const timeout = setTimeout(init, 1500);
  init();

  function init() {
    const privacyPolicy = getPrivacyPolicy();
    const privacyPolicyCloseButton = getPrivacyPolicyCloseButton();

    if (privacyPolicy && privacyPolicyCloseButton) {
      window.removeEventListener('load', init, false);
      clearTimeout(timeout);

      const reposition = () => {
        if (privacyPolicy) {
          const height = privacyPolicy.offsetHeight;
          animateTransform({ y: -height, duration: 0 });
        }
      };

      const close = () => {
        window.removeEventListener('load', reposition, false);
        window.removeEventListener('resize', reposition, false);
        animateTransform({ y: 0, duration: 1500 });
      };

      reposition();
      privacyPolicyCloseButton.addEventListener('click', close, false);
      window.addEventListener('load', reposition, false);
      window.addEventListener('resize', reposition, false);
      return true;
    }

    return false;
  }
}; */

module.exports = {
  setVisible,
  setZIndex,
  dismiss,
  onChatOpened,
  onChatClosed,
  toggleChat,
  chatToggleCallback,
  animateTransform,
  adaReadyCallbacks,
  onAdaReady,
  // avoidPrivacyPolicy,
};

==> gatsby-plugin-ada-chatbot-1.4.2.tgz: package/src/actions.js <==
const {
  adaRootSelector,
  getAdaRoot,
  chatFrameSelector,
} = require('./elements');

let transformStyles = null;

const setVisible = (visibility = true) => {
  const adaRoot = getAdaRoot();
  if (adaRoot) {
    if (visibility) adaRoot.classList.add('ada-chatbot-visible');
    else adaRoot.classList.remove('ada-chatbot-visible');
  }
};

const setZIndex = (zIndex) => {
  const adaRoot = getAdaRoot();
  if (adaRoot) adaRoot.style.zIndex = zIndex;
};

const dismiss = (pluginOptions) => {
  try {
    const { dismissDuration } = pluginOptions;

    document.documentElement.classList.add('ada-chatbot-dismissed');

    if (dismissDuration === 'session') {
      sessionStorage.setItem('ada-chatbot-dismissed', 'true');
    } else if (typeof dismissDuration === 'number') {
      const expires = Date.now() + (dismissDuration * 60 * 60 *1000);
      localStorage.setItem('ada-chatbot-dismissed', 'true');
      localStorage.setItem('ada-chatbot-dismiss-expires', expires);
    }
    
    return true;
  } catch(e) {
    return false;
  }
};

const adaReadyCallbacks = [];
const onAdaReady = (callback) => {
  if (typeof callback === 'function') adaReadyCallbacks.push(callback);
  if (window.adaEmbed) {
    while (adaReadyCallbacks.length) {
      const adaReadyCallback = adaReadyCallbacks.shift();
      adaReadyCallback(window.adaEmbed);
    }
  }
};

const chatOpenedCallbacks = [];
const onChatOpened = (callback) => {
  if (typeof callback === 'function') chatOpenedCallbacks.push(callback);
};

const chatClosedCallbacks = [];
const onChatClosed = (callback) => {
  if (typeof callback === 'function') chatClosedCallbacks.push(callback);
};

const toggleChat = async () => {
  if (window && window.adaEmbed) {
    setVisible(true);
    const toggled = await window.adaEmbed.toggle();
    return toggled;
  }
  return false;
};

const chatToggleCallback = (isChatOpen) => {
  if (isChatOpen) {
    document.documentElement.classList.add('ada-chatbot-chat-open');
    chatOpenedCallbacks.forEach(callback => callback(window.adaEmbed));
  }
  else {
    document.documentElement.classList.remove('ada-chatbot-chat-open');
    chatClosedCallbacks.forEach(callback => callback(window.adaEmbed));
  }
};

const animateTransform = ({ x = 0, y = 0, duration = 150, easing = 'ease-in-out' } = {}) => {
  const adaRoot = getAdaRoot();
  const transform = `translate(${x}px, ${y}px)`;
  const transition = `transform ${duration}ms ${easing}`;

  if (!transformStyles) transformStyles = document.createElement('style');

  transformStyles.innerHTML = `
    ${adaRootSelector} {
      transition: ${transition};
      transform: ${transform};
    }

    ${chatFrameSelector} {
      margin-bottom: ${y}px !important;
      margin-right: ${x}px !important;
    }
  `;

  if (adaRoot) adaRoot.appendChild(transformStyles);
};

/* Temporarily removed
const avoidPrivacyPolicy = () => {
  window.addEventListener('load', init, false);
  const timeout = setTimeout(init, 1500);
  init();

  function init() {
    const privacyPolicy = getPrivacyPolicy();
    const privacyPolicyCloseButton = getPrivacyPolicyCloseButton();

    if (privacyPolicy && privacyPolicyCloseButton) {
      window.removeEventListener('load', init, false);
      clearTimeout(timeout);

      const reposition = () => {
        if (privacyPolicy) {
          const height = privacyPolicy.offsetHeight;
          animateTransform({ y: -height, duration: 0 });
        }
      };

      const close = () => {
        window.removeEventListener('load', reposition, false);
        window.removeEventListener('resize', reposition, false);
        animateTransform({ y: 0, duration: 1500 });
      };

      reposition();
      privacyPolicyCloseButton.addEventListener('click', close, false);
      window.addEventListener('load', reposition, false);
      window.addEventListener('resize', reposition, false);
      return true;
    }

    return false;
  }
}; */

module.exports = {
  setVisible,
  setZIndex,
  dismiss,
  onChatOpened,
  onChatClosed,
  toggleChat,
  chatToggleCallback,
  animateTransform,
  adaReadyCallbacks,
  onAdaReady,
  // avoidPrivacyPolicy,
};
